何以为家 (豆瓣)
Description: 何以为家电影简介和剧情介绍,何以为家影评、图片、预告片、影讯、论坛、在线购票
Keywords: 何以为家,كفرناحوم,何以为家影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.38豆瓣电影Top250

# 何以为家 كفرناحوم (2018)

导演: 娜丁·拉巴基
编剧: 娜丁·拉巴基 / 吉哈德·霍加里 / 米歇尔·凯斯沃尼 / 乔治斯·哈巴兹 / 哈立德·穆扎纳
主演: 赞恩·阿尔·拉菲亚 / 约丹诺斯·希费罗 / 博鲁瓦蒂夫·特雷杰·班科尔 / 卡萨尔·艾尔·哈达德 / 法迪·尤瑟夫 / 海塔·塞德拉·伊扎姆 / 阿拉·乔什涅 / 娜丁·拉巴基 / 埃利亚斯·库利 / 努尔·艾尔·侯赛尼
类型: 剧情
制片国家/地区: 黎巴嫩 / 美国 / 法国 / 塞浦路斯 / 卡塔尔 / 英国
语言: 阿拉伯语 / 阿姆哈拉语
上映日期: 2019-04-29(中国大陆) / 2018-05-17(戛纳电影节) / 2018-09-20(黎巴嫩)
片长: 126分钟 / 117分钟(中国大陆)
又名: 迦百农 / 星仔打官司(港) / 我想有个家(台) / Cafarnaúm / Capernaum / Capharnaüm
IMDb: tt8267604
豆瓣评分
引用
9.1
990184人评价
5星
60.0%
4星
34.0%
3星
5.5%
2星
0.4%
1星
0.2%
好于 98% 剧情片
想看 看过
评价:
推荐

## 何以为家的剧情简介 · · · · · ·

法庭上，十二岁的男孩赞恩向法官状告他的亲生父母，原因是，他们给了他生命。是什么样的经历让一个孩子做出如此不可思议的举动？故事中，赞恩的父母在无力抚养和教育的状况下依然不停生育，作为家中的长子赞恩，弱小的肩膀承担了无数生活的重压。当妹妹被强行卖给商贩为妻时，赞恩愤怒离家，之后遇到一对没有合法身份的母子，相互扶持勉强生活。然而生活并没有眷顾赞恩，重重磨难迫使他做出了令人震惊的举动……

## 何以为家的演职员 · · · · · · ( 全部 15 )

- 娜丁·拉巴基 导演
- 赞恩·阿尔·拉菲亚 饰 赞恩 Zain
- 约丹诺斯·希费罗 饰 拉希尔 Rahil
- 博鲁瓦蒂夫·特雷杰·班科尔 饰 约纳斯 Yonas
- 卡萨尔·艾尔·哈达德 饰 苏阿德 Souad, the Mother
- 法迪·尤瑟夫 饰 塞利姆 Selim, the Father

## 何以为家的视频和图片 · · · · · · ( 预告片8 | 视频评论4 · 添加 | 图片1031 · 添加 )

## 何以为家的获奖情况 · · · · · · ( 全部 )

- 第91届奥斯卡金像奖
- 最佳外语片(提名)
- 娜丁·拉巴基

- 第71届戛纳电影节
- 主竞赛单元 金棕榈奖(提名)
- 娜丁·拉巴基

- 第76届金球奖
- 电影类 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  饮食男女

  82年生的金智英

  小偷家族

  寻梦环游记

  海蒂和爷爷

  海边的曼彻斯特

  海街日记

  阳光普照

  我是山姆

  摔跤吧！爸爸

我要写短评

## 何以为家的短评 · · · · · · ( 全部 252959 条 )

热门 / 最新 / 好友

### 17454 有用 西楼尘 看过 2018-06-27 14:18:36

见过游乐园女神被扒光，洗过沾了鲜血的衣服，听过蜘蛛侠变成蟑螂侠的传闻。才知道美丽会变丑陋，纯净会变脏臭，英雄泯然众人，自己却无能为力。把童贞交给世界，用匕首刺穿丑陋，靠起诉状告父母，挤笑脸嘲弄命运。赞恩把婴儿交给男人，才明白自己谁都保护不了。他就站在破败的街角，仿佛人生走到尽头。

### 11383 有用 同志亦凡人中文站 看过 2018-08-05 13:23:07

拍给生育癌看的。我就不说卖惨了，因为是真惨。善良而倔强的叙利亚小男孩，默默把全世界扛在瘦弱的肩上，拖着生活往前走。最后他露出全片唯一一个微笑我一下就泪奔了。孩子永远是我的软肋，我给你五星还不行么...

### 8184 有用 喂你这是 看过 2018-06-17 20:53:58

人类究竟为什么对生育有这么大的执念？

### 6266 有用 水怪 看过 2018-05-18 04:11:38

在欧陆人民面前，中东这样的超级人道主义灾难本身就是泪点满满。这样的题材如果是纪录片会更具力量，但想想如此年纪的男主及孩童们居然可以“演绎”得如此逼近现实，女导演的确强大。另外强烈抄送国内逼婚逼生一族。

### 8427 有用 朝暮雪 看过 2019-03-05 14:46:00

在这里，女孩是一种商品，可以换钱；男孩是一种工具，负责养家糊口、照顾更小的小孩。 父母只管生，不管养，将孩子当做摇钱树和免费劳动力。他们不但不能给孩子带来快乐，只会给他们带来苦难和折磨。 现在做什么都要考证，做父母却不需要考证。然而并不是所有人都配当父母，也并不是生了孩子就自动成为妈妈。 他们只图一时的快活，让孩子跟着他们来到这个世界一起受苦，他们根本不配做父母。 如果不能给予孩子幸福，当初就不应... 在这里，女孩是一种商品，可以换钱；男孩是一种工具，负责养家糊口、照顾更小的小孩。 父母只管生，不管养，将孩子当做摇钱树和免费劳动力。他们不但不能给孩子带来快乐，只会给他们带来苦难和折磨。 现在做什么都要考证，做父母却不需要考证。然而并不是所有人都配当父母，也并不是生了孩子就自动成为妈妈。 他们只图一时的快活，让孩子跟着他们来到这个世界一起受苦，他们根本不配做父母。 如果不能给予孩子幸福，当初就不应该把他们生下来。 他们是你的孩子，但他们更是他们自己，他们有自己的人格和思想，不应该被虐待，更不应该被贩卖。 父母有管教孩子的义务，孩子也有权利将父母告上法庭。 赞恩什么都不要，他只要父母别再生了。 因为一个人在还没有学会如何做一名合格的父母之前，Ta不配拥有孩子，更不配当爸爸（妈妈）。 (展开)

> 更多短评 252959条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 何以为家的影评 · · · · · · ( 全部 4785 条 )

热门 / 最新 / 好友
网友小西 2019-03-02 17:13:00

## 看完这种类型的影片后，我们必须自问的三个问题

1 我们看这类“边缘底层视角”的影片之后究竟应该明白什么？ 2 身不由己的作恶者（影片中卖掉女儿的父母）应该受到惩罚吗？ 3 人该如何面对阶级和个人命运问题？ 在回答这些问题之前，我们先来看看影片本身。 主角赞恩的故事其实很有层次感。影片一开始直接的制造差异和矛盾，... (展开)
12240 123 905回应 收起
包子 2019-05-01 22:59:45 #《迦百农》对社会问题进行了哪些探讨？

## 这个清醒的小男孩，太让人心疼了

这篇影评可能有剧透

中国版海报上的一句宣传语非常引人注目： 我要控告我的父母，因为他们生下了我。——赞恩 黎巴嫩女导演拉巴基以她独特的视角和方式，呈现了这个发生在黎巴嫩贫民窟中的叙利亚难民的故事： 年龄不详、据说是12岁左右的男主角赞恩，与父母、兄弟姐妹为了躲避 叙利亚战争，非法生... (展开)
7386 36 431回应 收起
小鱼闲倌 2019-04-05 00:06:49

## 《迦百农》：“你为什么要起诉父母？因为生了我。”

这篇影评可能有剧透

1 “你为什么要生下我？” 我很少写影评，如果不得不写的话，要么是因为片子太好，要么是片子太烂，又或者是片子太烂被人说得太好，或者是片子太好被人说得太烂。 《迦百农》属于第一种，好到让人心疼的那种。 相比于内地的新译名《何以为家》，我更喜欢其直译名《迦百农》。迦... (展开)
2884 58 419回应 收起
黄小邪 2019-01-06 13:22:08

## 迦百农

与两友在纽约film forum看黎巴嫩导演Nadine Labaki新片《迦百农》（2018），戛纳评审团奖。一友哭得很惨；我极力克制与分析，也有一段没忍住眼泪（似乎是第一次出现监狱那场，感觉到了、读导演访谈也印证了，那是真的监狱、真的犯人，很多孤苦无依的小孩，很多“非法移民”，大... (展开)
1014 27 149回应 收起
水木丁 2019-05-03 09:23:49

## 像你这样的孩子存在这世界上，让我稍微对这世界有了些期待。

每年的北京电影节都会盲选一两部不熟悉国家的电影来看，这次是黎巴嫩电影《何以为家》，电影的原名叫《迦百农》，看电影之前，我去查了下资料，主要说这是圣经中的一个地名，是耶稣被迫离开家乡后曾经停留过的一个地方，在这里传道，据说这里出现过很多神迹。 我看到还有一个引... (展开)
1102 29 73回应 收起
姨妈的鸭 2019-05-02 15:01:06 #关于《迦百农》的看点汇总

## 父母不过是倒数第二块多米诺骨牌而已

假如你只是为了这一张截图而走进电影院，那你会失望的。 影评称述式的在讲述一个少年犯动手前的一小段人生，但是，这不仅仅是父母的问题，当然我也说不清到底指责了多少问题，因为影片里和现实里的问题真的太多了，我指责不过来了。 我们当然可以把问题很浅薄的归结到父母身上... (展开)
864 21 121回应 收起
白头豕 2019-05-05 01:24:50 #《迦百农》对社会问题进行了哪些探讨？

## 本当是黎巴嫩《三毛流浪记》，原来是欧洲的《郭巨埋儿》

这篇影评可能有剧透

迷信马尔萨斯的白左们又在无耻地给穷人们推销计划生育了。 看这部电影的过程中，我为电影描述出来的许多真实的苦难流了不少的眼泪，也一直在等待真正的主题浮出来。 所有描述苦难的电影，包括纪录片在内，都需要有一个共同的主题，那就是诠释出苦难的原因，并激发人们将之改变... (展开)
940 349 519回应 收起
KidCoolAF 2019-03-08 10:17:05

## 用尽全力的绝望

我一直告诉你，“你儿子还没有出生就已经死了”，他并不存在，即使是番茄酱也有名字，有生产日期和到期日期。 当一个地区连宗教都无法维护秩序时，它就真正地进入了一种最为原始的混乱。黎巴嫩女导演Nadine Nabaki第三部剧情长片《迦百农》继续探讨黎巴嫩严重的社会公平问题。 ... (展开)
547 11 41回应 收起
果麦文化 2019-05-05 15:37:00

## 《何以为家》的译名很好玩

谈谈《何以为家》的几个译名吧，很有意思。 第一个，直译的《迦百农》。很多人说这个其实比《何以为家》更贴近电影的灵魂和文化内核，确实没错。 迦百农，英文叫做Capernaum，这其实是圣经新约里的一个地名，也是耶稣曾经传道的地方。 它曾是一座无比繁华的犹太城、港口城市，... (展开)
293 4 46回应 收起
碧浪达 2019-04-29 22:22:54

## 献给电影院坐我身边的三个傻逼。

这篇影评可能有剧透

《何以为家》真的是部好电影，整个过程如鲠在喉，但是眼泪怎么都落不下来，作为艺术电影干净利落没有炫技的手法和矫情的剧情。 有个细节，男主赞恩裤子的logo是美国队长的盾牌，可是虚拟的超级英雄并不能拯救身为难民，处于国家战争中的赞恩。甚至不能解救十一岁就被卖给别人当... (展开)
208 38 218回应 收起

> 更多影评 4785篇

添加新讨论

## 讨论区 · · · · · ·

想知道黑人小婴儿和女主也是导演随机找的难民吗？ | 来自黑色饼干 | 26 回应 | 2022-11-22 23:02:52
婴儿为什么和偷渡者在一起？没被卖给收养人？ | 来自super fun | 1 回应 | 2022-11-22 22:58:38
感恩我能生在大中国！ | 来自TiAmo | 6 回应 | 2022-11-19 20:46:19
愿所有善良的孩子都能被世界温柔以待 | 来自桃味面包崽 | 1 回应 | 2022-11-16 21:43:18
你们觉得zain父母本身有错吗？ | 来自昕 | 209 回应 | 2022-11-16 21:40:08

> 去这部影片的讨论区（全部970条）

## 关于《何以为家》的问题 · · · · · · ( 全部31个 )

- 造假身份的人为什么要画四百刀把小黑宝宝买走关在小黑屋里？ 3人回答
- 男孩卖的药粉溶成的饮料是什么意思？ 4人回答

> 全部31个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 优酷视频 VIP免费观看
- 芒果TV VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

## 谁在看这部电影 · · · · · ·

- 墨央子
  1分钟前 看过
- 豆友196234576
  2分钟前 看过
- 再见白丝
  4分钟前 想看

1706822人看过 / 450597人想看

订阅何以为家的评论:
feed: rss 2.0